/*
 * This program prints disk information for the given disk.
 * The default is the current drive.
 *
 * This program was created by Rob Lindeman (gogo), repas GmbH
 */

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <sys/disk.h>

static char *usage_msg[] =  {
  "[ drive ]" ,
  "where: drive is the drive to display the information for.",
  NULL
};

/* -------------------------------------------------------------------------- */

main( int argc, char *argv[] )
{
  int fd;
  char bitmap[100];
  struct _disk_entry d_buf;
  long f_blocks,
       t_blocks;

  if( need_usage( argv ) )  {
    usage( EXIT_SUCCESS, *argv, usage_msg );
  }

  bitmap[0] = '\0';
  while( --argc )  {
    strcpy( &bitmap[0], &argv[argc][0] );
  }
  strcat( &bitmap[0], "/.bitmap" );

  if( ( fd = open( &bitmap[0], O_RDONLY ) ) == -1 )  {
    printf( "DISK_INFO: main-> Could not open %s\n", &bitmap[0] );
    sleep( 1 );
    exit( -1 );
  }

  if( disk_get_entry( fd, &d_buf ) )  {
    printf( "DISK_INFO: main-> Could not get disk info.\n" );
    exit( -1 );
  }

  if( disk_space( fd, &f_blocks, &t_blocks ) )  {
    printf( "DISK_INFO: main-> Could not get size info.\n" );
    exit( -1 );
  }

  close( fd );

  printf( "Information about drive /dev/%s:\n\n", &d_buf.driver_name[0] );
  printf( "Drive Type             : " );
  switch( d_buf.disk_type )  {
    case _UNMOUNTED:
      printf( "Not Mounted\n" );
      break;

    case _FLOPPY   :
      printf( "Floppy Disk\n" );
      break;

    case _HARD     :
      printf( "Fixed Disk\n" );
      break;

    case _RAMDISK  :
      printf( "RAM Disk\n" );
      break;

    case _REMOVABLE:
      printf( "Removable\n" );
      break;
  }
  printf( "Disk Name              : /dev/%s\n", d_buf.driver_name );
  printf( "Disk Sectors           : %ld\n", d_buf.disk_sectors );
  printf( "Partition Sectors      : %ld\n", d_buf.num_sectors );
  printf( "Cyclinders             : %u\n", d_buf.cylinders );
  printf( "Heads                  : %u\n", d_buf.heads );
  printf( "Sectors per Track      : %u\n", d_buf.track_sectors );
  printf( "Partition Offset       : %ld\n", d_buf.blk_offset );
  printf( "Disk Size              : %ld Mb (%ld Blocks)\n", d_buf.disk_sectors / 2, d_buf.disk_sectors );
  printf( "Free Partition Space   : %ld/%ld Mb (%ld/%ld Blocks)\n", f_blocks / 2, t_blocks / 2, f_blocks , t_blocks );
}

/* -------------------------------------------------------------------------- */


