/*
 * This program supplies general system information.
 *
 * This program was created by Rob Lindeman (gogo), repas GmbH
 */

#include <stdio.h>
#include <stdlib.h>
#include <sys/osinfo.h>

static char *usage_msg[] =  {
  "[ node ]",
  "where: node is the node to display system information for.",
  NULL
};

/* -------------------------------------------------------------------------- */

main( int argc, char *argv[] )
{
  struct _osinfo osinfo;
  int node = 0;

  if( need_usage( argv ) )  {
    usage( EXIT_SUCCESS, *argv, usage_msg );
  }

  while( --argc )  {
    node = atoi( argv[argc] );
  }

  if( qnx_osinfo( node, &osinfo ) == -1 ) {
    printf( "OSINFO: Error gathering information!\n" );
    exit( -1 );
  }

  printf( "Information about node %ld:\n\n", osinfo.nodename );
  printf( "OS Version             : %d.%02d%c\n", osinfo.version / 100, osinfo.version % 100, osinfo.release );
  printf( "CPU Mode               : %s ", osinfo.machine );

  if( osinfo.sflags & _PSF_PROTECTED )  {
    printf( "Protected Mode\n" );
  }
  else  {
    printf( "Real Mode\n" );
  }

  printf( "CPU Type               : 80%ld\n", osinfo.cpu );
  printf( "CPU Speed              : %d\n", osinfo.cpu_speed );
  printf( "Math Co-processor      : " );

  if( osinfo.sflags & _PSF_EMULATOR_INSTALLED )  {
    printf( "Emulated\n" );
  }
  else  {
    if( osinfo.sflags & _PSF_NDP_INSTALLED )  {
      if( ( osinfo.fpu == 87L )  ||
          ( osinfo.fpu == 287L )  ||
          ( osinfo.fpu == 387L ) )  {
        printf( "Present\n" );
      }
      else  {
        printf( "Unknown\n" );
      }
    }
    else  {
      printf( "None\n" );
    }
  }

  printf( "Primary Display Type   : " );
  choose_monitor( osinfo.primary_monitor );
  printf( "Secondary Display Type : " );
  choose_monitor( osinfo.secondary_monitor );
  printf( "Free Memory            : %dk/%dk\n", osinfo.freememk, osinfo.totmemk );
  printf( "Booted from            : " );

  switch( osinfo.bootsrc )  {
    case 'F':
      printf( "Floppy\n" );
      break;

    case 'H':
      printf( "Hard Disk\n" );
      break;

    case 'N':
      printf( "Network\n" );
      break;
  }

  printf( "DOS Flag               : " );

  if( osinfo.sflags & _PSF_RESERVE_DOS )  {
    printf( "Set\n" );
  }
  else  {
    printf( "Not Set\n" );
  }

  printf( "Password Protection    : " );

  if( osinfo.sflags & _PSF_PASSWORDS_ON )  {
    printf( "On\n" );
  }
  else  {
    printf( "Off\n" );
  }
}

/* -------------------------------------------------------------------------- */

void choose_monitor( int monitor )
{
  switch( monitor )  {
    case _MONITOR_NONE      :           
      printf( "None\n" );
      break;
    case _MONITOR_MONO      :           
      printf( "Monochrome\n" );
      break;
    case _MONITOR_CGA       :           
      printf( "CGA Color\n" );
      break;
    case _MONITOR_EGA_COLOR :           
      printf( "EGA Color\n" );
      break;
    case _MONITOR_EGA_MONO  :           
      printf( "EGA Monochrome\n" );
      break;
    case _MONITOR_PGS       :           
      printf( "PGS\n" );
      break;
    case _MONITOR_VGA_MONO  :           
      printf( "VGA Monochrome\n" );
      break;
    case _MONITOR_VGA_COLOR :           
      printf( "VGA Color\n" );
      break;
    case _MONITOR_PS30_MONO :           
      printf( "PS/2 Model 30 Monochrome\n" );
      break;
    case _MONITOR_PS30_COLOR:           
      printf( "PS/2 Model 30 Color\n" );
      break;
    default:
      printf( "Unknown\n" );
      break;
  }
}

/* -------------------------------------------------------------------------- */


